import { Component, ViewEncapsulation, AfterViewInit } from '@angular/core';
import { TdLoadingService } from '@covalent/core';
import { GridOptions, IGetRowsParams, IRowModel } from 'ag-grid/main';

import { StatementBase } from '../../../models/statement.base';

import { RoadServiceService } from '../../../services/road-service.service';
import { RoadService } from '../../../models/road-service';
import { EditorComponent } from '../../../helpers/editor.component';
import { RendererComponent } from '../../../helpers/renderer.component';
import { RoadServiceCreateService } from '../../../services/road-service-create.service';
import { RegionSelectList } from '../../../models/region-select-list';
import { RoadSelectList } from '../../../models/road-select-list';
import { RoadDirectionSelectList } from '../../../models/road-direction-select-list';
import { OrganizationSelectList } from '../../../models/organization-select-list';

import { routerTransition } from '../../../animations/router.animation';

@Component({
    // tslint:disable-next-line:component-selector
    selector: 'road-service-grid',
    templateUrl: 'road-service.component.html',
    styleUrls: ['road-service.scss'],
    encapsulation: ViewEncapsulation.None,
})
export class RoadServiceComponent extends StatementBase {

    public regions: RegionSelectList[];
    public roads: RoadSelectList[];
    public roadDirections: RoadDirectionSelectList[];
    public organizations: OrganizationSelectList[];

    constructor(
        protected service: RoadServiceService,
        protected dataService: RoadServiceCreateService,
        protected loadingService: TdLoadingService,
    ) {
        super();
    }

  protected createColumnDefs(): any[] {
    return [
      {
        headerName: '#',
        width: 30,
        checkboxSelection: true,
        suppressSorting: true,
        suppressMenu: true,
        pinned: true,
      },
      {
        headerName: 'ID',
        field: 'id',
      },
      {
        headerName: 'Назва дороги',
        field: 'roadId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.roads,
          valueCol: 'roadId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Область',
        field: 'regionId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.regions,
          valueCol: 'regionId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Місцезнаходження, км+ початок',
        field: 'begin',
        editable: true,
      },
      {
        headerName: 'Місцезнаходження, км+ кінець',
        field: 'end',
        editable: true,
      },
      {
        headerName: 'Напрямок смуги руху',
        field: 'roadDirectionId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.roadDirections,
          valueCol: 'roadDirectionId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Назва організації чи підприємства, що обслуговує ділянку дороги',
        field: 'organizationId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.organizations,
          valueCol: 'id',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Рік початку обслуговування',
        field: 'yearBegin',
        editable: true,
      },
    ];
  }

  protected initFunction(): void {
    this.dataService.getModels().then((models: any) => {
            this.regions = models.regionSelectListDsM as RegionSelectList[];
            this.roads = models.roadSelectListDsM as RoadSelectList[];
            this.roadDirections = models.roadDirectionSelectListDsM as RoadDirectionSelectList[];
            this.organizations = models.organizationSelectListDsM as OrganizationSelectList[];
      }).then(() => {
            this.bootstrapGrid();
      });
  }
}
