import {Component, ViewEncapsulation} from '@angular/core';
import {GridOptions} from 'ag-grid/main';
import { TdLoadingService } from '@covalent/core';

import { StatementBase } from '../../../models/statement.base';

import { RoadSurfaceService } from '../../../services/road-surface.service';
import { RoadSurface } from '../../../models/road-surface';
import { EditorComponent } from '../../../helpers/editor.component';
import { RendererComponent } from '../../../helpers/renderer.component';
import { RoadSurfaceCreateService } from '../../../services/road-surface-create.service';
import { RegionSelectList } from '../../../models/region-select-list';
import { RoadSelectList } from '../../../models/road-select-list';
import { RoadDirectionSelectList } from '../../../models/road-direction-select-list';
import { SurfaceTreatmentSelectList } from '../../../models/surface-treatment-select-list';
import { StateCommonSelectList } from '../../../models/state-common-select-list';
import { SurfaceTypeSelectList } from '../../../models/surface-type-select-list';

import { routerTransition } from '../../../animations/router.animation';

@Component({
    selector: 'road-surface',
    templateUrl: 'road-surface.component.html',
    styleUrls: ['road-surface.scss'],
    encapsulation: ViewEncapsulation.None,
})
export class RoadSurfaceComponent extends StatementBase {

    public regions: RegionSelectList[];
    public roadDirection: RoadDirectionSelectList[];
    public roads: RoadSelectList[];
    public surfaceTypes: SurfaceTypeSelectList[];
 public states: StateCommonSelectList[];
    public surfaceTreatment: SurfaceTreatmentSelectList[];

    constructor(
        protected service: RoadSurfaceService,
        protected dataService: RoadSurfaceCreateService,
        protected loadingService: TdLoadingService,
    ) {
        super();
    }

  protected createColumnDefs(): any[] {
    return [
      {
        headerName: '#',
        width: 30,
        checkboxSelection: true,
        suppressSorting: true,
        suppressMenu: true,
        pinned: true,
      },
      {
        headerName: 'ID',
        field: 'id',
      },
      {
        headerName: 'Назва дороги',
        field: 'roadId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.roads,
          valueCol: 'roadId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Область',
        field: 'regionId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.regions,
          valueCol: 'regionId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Напрямок смуги руху',
        field: 'roadDirectionId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.roadDirection,
          valueCol: 'roadDirectionId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Місцезнаходження, км+ початок',
        field: 'begin',
        editable: true,
      },
      {
        headerName: 'Місцезнаходження, км+ кінець',
        field: 'end',
        editable: true,
      },
      {
        headerName: 'Тип покриття',
        field: 'surfaceTypeId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.surfaceTypes,
          valueCol: 'surfaceTypeId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Тип поверхневої обробки',
        field: 'surfaceTreatmentId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.surfaceTreatment,
          valueCol: 'surfaceTreatmentId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Стан покриття',
        field: 'stateCommonId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.states,
          valueCol: 'stateCommonId',
          labelCol: 'value',
        },
      },
    ];
  }

  protected initFunction(): void {
    this.dataService.getModels().then((models: any) => {
            this.regions = models.regionSelectListDsM as RegionSelectList[];
            this.roads = models.roadSelectListDsM as RoadSelectList[];
            this.roadDirection = models.roadDirectionSelectListDsM as RoadDirectionSelectList[];
            this.surfaceTypes = models.surfaceTypeSelectListDsM as SurfaceTypeSelectList[];
            this.states = models.stateCommonSelectListDsM as StateCommonSelectList[];
            this.surfaceTreatment = models.surfaceTreatmentSelectListDsM as SurfaceTreatmentSelectList[];
      }).then(() => {
            this.bootstrapGrid();
      });
  }

  // tslint:disable-next-line:member-ordering
  public CreateModel(): Object {
    return new RoadSurface();
  }
}
