import { Component, ViewEncapsulation, AfterViewInit } from '@angular/core';
import { TdLoadingService } from '@covalent/core';
import { GridOptions, IGetRowsParams, IRowModel } from 'ag-grid/main';

import { StatementBase } from '../../../models/statement.base';

import { SettlementAddressLinkService } from '../../../services/settlement-address-link.service';
import { SettlementAddressLink } from '../../../models/settlement-address-link';
import { EditorComponent } from '../../../helpers/editor.component';
import { RendererComponent } from '../../../helpers/renderer.component';
import { SettlementAddressLinkCreateService } from '../../../services/settlement-address-link-create.service';
import { RegionSelectList } from '../../../models/region-select-list';
import { RoadSelectList } from '../../../models/road-select-list';
import { SettlementSelectList } from '../../../models/settlement-select-list';
import { SettlementLocationSelectList } from '../../../models/settlement-location-select-list';

import { routerTransition } from '../../../animations/router.animation';

@Component({
    // tslint:disable-next-line:component-selector
    selector: 'bus-grid',
    templateUrl: 'settlement-address-link.component.html',
    styleUrls: ['settlement-address-link.scss'],
    encapsulation: ViewEncapsulation.None,
})
export class SettlementAddressLinkComponent extends StatementBase {

    public regions: RegionSelectList[];
    public settlements: SettlementSelectList[];
    public roads: RoadSelectList[];
    public settlementLocations: SettlementLocationSelectList[];

    constructor(
        protected service: SettlementAddressLinkService,
        protected dataService: SettlementAddressLinkCreateService,
        protected loadingService: TdLoadingService,
    ) {
        super();
    }

  protected createColumnDefs(): any[] {
    return [
      {
        headerName: '#',
        width: 30,
        checkboxSelection: true,
        suppressSorting: true,
        suppressMenu: true,
        pinned: true,
      },
      {
        headerName: 'ID',
        field: 'id',
      },
      {
        headerName: 'Назва дороги',
        field: 'roadId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.roads,
          valueCol: 'roadId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Область',
        field: 'regionId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.regions,
          valueCol: 'regionId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Місцезнаходження, км+ початока',
        field: 'begin',
        editable: true,
      },
      {
        headerName: 'Місцезнаходження, км+ кінець',
        field: 'end',
        editable: true,
      },
      {
        headerName: 'Місце',
        field: 'settlementLocationId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.settlementLocations,
          valueCol: 'id',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Назва населенного пункту',
        field: 'settlementId',
        editable: true,
        cellEditorFramework: EditorComponent,
        cellRendererFramework: RendererComponent,
        cellEditorParams: {
          data: this.settlements,
          valueCol: 'settlementId',
          labelCol: 'name',
        },
      },
      {
        headerName: 'Відстань від проїзної частини до забудови, м',
        field: 'distance',
        editable: true,
      },
    ];
  }

  protected initFunction(): void {
    this.dataService.getModels().then((models: any) => {
            this.regions = models.regionSelectListDsM as RegionSelectList[];
            this.settlements = models.settlementSelectListDsM as SettlementSelectList[];
            this.roads = models.roadSelectListDsM as RoadSelectList[];
            this.settlementLocations = models.settlementLocationSelectListDsM as SettlementLocationSelectList[];
      }).then(() => {
            this.bootstrapGrid();
      });
  }
}
